Client

Struct Client 

pub struct Client { /* private fields */ }

Implementations

Source

impl Client

pub fn builder() -> ClientBuilder

Create a new client builder that uses environment variables as defaults.

You can override any values using the builder methods:

  • .with_project() - override project
  • .with_location() - override location
  • .with_credentials() - override credentials

Example:

// Use all env vars
let client = Client::builder().build()?;

// Override just the location
let client = Client::builder().with_location("us-central1").build()?;

// Override project and location
let client = Client::builder()
    .with_project("my-project")
    .with_location("us-central1")
    .build()?;
pub fn new() -> Result<Self, VertexAiClientError>

Create a new client using environment variables for project, location, and credentials.

Reads from:

  • GOOGLE_CLOUD_PROJECT (required)
  • GOOGLE_CLOUD_LOCATION (optional, defaults to “global”)
  • GOOGLE_CLOUD_SERVICE_ACCOUNT (optional, for service account impersonation)
pub fn from_env() -> Result<Self, VertexAiClientError>

Create a client using environment variables for project, location, and credentials.

This is a convenience method that calls the ProviderClient::from_env() trait method. Reads from:

  • GOOGLE_CLOUD_PROJECT (required)
  • GOOGLE_CLOUD_LOCATION (optional, defaults to “global”)
  • GOOGLE_CLOUD_SERVICE_ACCOUNT (optional, for service account impersonation)
pub fn project(&self) -> &str

pub fn location(&self) -> &str

pub async fn get_inner(&self) -> Result<&PredictionService, VertexAiClientError>